function [r,F] = IceActions(Run,data)

x = data.body.x;
z = data.body.z;

g       = data.env.g;
rho_w   = data.env.rho;
rho_i   = data.ice.rho;

E       = data.ice.E;
sigmaf  = data.ice.sigmaf;
nu      = data.ice.nu;

mu = data.ice.mu;

KG = data.body.KG;
d  = data.body.d;

%% Diameter of bouy
D = 2*x(find( z == 0));

%% Slopeangel in waterline
alpha0 = atan(z(find(z ==0)-1)/(x(find(z==0)) - x(find( z == 0)-1)));

%% Calculations

i=1;
for h = Run.Hice(1):(Run.Hice(2)-Run.Hice(1))/50:Run.Hice(2)
    if h ~= 0
        %% Ralston:
        if i == 1 || ( Run.Hice(1) == 0 && i == 2 )
            eta5 = 0;
            eta3 = 0;
            eta1 = 0;
        else
            eta5 = r(5,1,i-1);
            eta3 = r(3,1,i-1);
            eta1 = r(1,1,i-1);
        end
        %% rho-coefficient
        e = 10;
        rho = 2;
        while e > 0.0001
            f = rho-log(rho)+(.166*rho+0.83e-1)*...
                (rho-1)^2*rho_w*g*D^2/(sigmaf*h)-1.369;
            df = 1-1/rho+.166*(rho-1)^2*rho_w*g*D^2/(sigmaf*h)+...
                2*(.166*rho+0.83e-1)*(rho-1)*rho_w*g*D^2/(sigmaf*h);
            rhon = rho - f/df;
            if rhon <= 1
                rhon = 1.001;
            end
            e = abs(rhon-rho);
            rho = rhon;
        end

        %% Ralston slope independant coefficients 
        A(1) = (1+2.711*rho*log(rho))/(3*(rho-1));
        A(2) = 0.075*(rho^2 + rho -2);
        %% Iteration for find static heel and drift-off
        iter = 1;
        while 1
            %% Corrected slope angle
            alpha = alpha0 + eta5;

            %% Full elliptic integrals
            [F_el,E_el] = ellipke(sin(alpha)^2);

            %% Functions
            h_ = cos(alpha) - mu/sin(alpha) * (E_el-cos(alpha)^2*F_el);
            f_ = sin(alpha) + mu*cos(alpha) * F_el;
            g_ = (0.5+alpha/sin(2*alpha))/(pi*sin(alpha)/4 + mu*alpha/tan(alpha));

            %% Coefficients        
            A(3) = 0.9/4/cos(alpha)*(1+mu*E_el/tan(alpha)) - mu*0.9/4/tan(alpha)*f_*g_;
            A(4) = tan(alpha)/(1-mu*g_);

            B(1) = h_/(pi/4*sin(alpha) + mu*alpha/tan(alpha));
            B(2) = 0.9/4*(pi/2*cos(alpha) - mu*alpha - f_*h_/(pi/4*sin(alpha) + mu*alpha/tan(alpha)));

            %% Diamter at max ice submergance
            Dt = 2*x(2);

            %% Forces
            FH = (A(1)*sigmaf*h^2 + A(2)*g*h*D^2 + A(3)*(rho_w-rho_i)*g*h*(D^2-Dt^2))*A(4);
            FV = B(1)*FH + B(2)* (rho_w-rho_i)*g*h*(D^2-Dt^2);

            %% Moment (assuming forces to attack at projected waterline crossing. Very conservative)
            M = -FH * (D/2 * sin(eta5) + d - KG) - FV * D/2 * cos(eta5);

            Fexc = [FH 0 FV 0 M 0]';

            rnow = zeros(6,3);
            rnow(1,1) = eta1;
            rnow(3,1) = eta3;
            rnow(5,1) = eta5;

            C    = Restoring(data,rnow,1,'no waves');
            Fr   = Restoring(data,rnow,2,'no waves');
            
            e = sqrt(  ((Fr(1)+Fexc(1))/Fexc(1))^2 + ((Fr(5)+Fexc(5))/Fexc(5))^2 );        

            if e < 0.001
                r(:,1,i) = rnow(:,1);
                F(:,1,i) = Fexc;
                break;
            elseif iter == 100;
                disp('No Convergance')
                r(:,1,i) = rnow(:,1);
                F(:,1,i) = Fexc;
                break
            else
                dr = sparseinv(C)*(Fexc+Fr);
                eta1 = eta1 + dr(1);
                eta3 = eta3 + dr(3);
                eta5 = eta5 + dr(5);
                iter = iter + 1;
            end
            
        end
        
        %% Croasdale
        if i == 1 || ( Run.Hice(1) == 0 && i == 2 )
            eta5 = 0;
            eta3 = 0;
            eta1 = 0;
        else
            eta5 = r(5,1,i-1);
            eta3 = r(3,1,i-1);
            eta1 = r(1,1,i-1);
        end
        %% Characteristic length
        l = (E*h^3/12/rho_w/g/(1-nu^2))^(1/4); 
        iter =1;
        while 1
            %% Corrected slope angle
            alpha = alpha0 + eta5;
            %% Timco-Cornett
            alphaTC = abs(alpha);

            ksi3 = mu*cos(alphaTC) - sin(alphaTC);
            ksi4 = mu*sin(alphaTC) + cos(alphaTC);

            C3 = 0.68*ksi3/ksi4;
            C4 = ksi3*(ksi3/ksi4 - cot(alphaTC));

            %% Forces
            FH = C3*D*sigmaf*(rho_w*g*h^5/E)^(1/4) * (1+pi^2*l/4/D) +...
                C4*D*-d*h*(rho_w-rho_i)*g;
            FV = FH * ksi3/ksi4;

            %% Moment (assuming forces to attack at projected waterline crossing. Very conservative)
            M = -FH * (D/2 * sin(eta5) + d - KG) - FV * D/2 * cos(eta5);

            Fexc = [FH 0 FV 0 M 0]';

            rnow = zeros(6,3);
            rnow(1,1) = eta1;
            rnow(3,1) = eta3;
            rnow(5,1) = eta5;

            C    = Restoring(data,rnow,1,'no waves');
            Fr   = Restoring(data,rnow,2,'no waves');
            
            e = sqrt(  ((Fr(1)+Fexc(1))/Fexc(1))^2 + ((Fr(5)+Fexc(5))/Fexc(5))^2 );        

            if e < 0.001
                r(:,2,i) = rnow(:,1);
                F(:,2,i) = Fexc;
                break;
            elseif iter == 100;
                disp('No Convergance')
                r(:,2,i) = rnow(:,1);
                F(:,2,i) = Fexc;
                break
            else
                dr = sparseinv(C)*(Fexc+Fr);
                eta1 = eta1 + dr(1);
                eta3 = eta3 + dr(3);
                eta5 = eta5 + dr(5);
                iter = iter + 1;
            end
        end
    else
        r(:,1,i) = zeros(6,1);
        r(:,2,i) = zeros(6,1);
        F(:,1,i) = zeros(6,1);
        F(:,2,i) = zeros(6,1);
    end
    i=i+1;       
end
end
