function [r F] = Newmark(Run, data, rnow)

if Run.model == 1 && Run.envload ==1 %%linear
    %% Integration constats
    dt        = Run.dt; %Length of each step
    gamma     = 0.5;    %No numerical damping
    beta      = 1/6;    %Linear acceleration
    
    a(1) = gamma/(beta*dt);
    a(2) = 1/(beta*dt^2);
    a(3) = 1/(beta*dt);
    a(4) = 1/(2*beta)-1; 
    a(5) = gamma/beta -1;
    a(6) = (gamma/(2*beta) -1)*dt;
    
    %% Mass matrix (linear)
    MA   = Inertia(data,zeros(6,3),1);
        
    %% Damping Matrix (linear)
    B    = Damping(data,zeros(6,3),Run,1);
    
    % Stiffness Matrix (linear)
    C    = Restoring(data,zeros(6,3),1,'linear');
    
    %% Contribution to Effectiv Stifness
    B_   = B  * a(1);
    MA_  = MA * a(2);
    
    C_ = C + B_ + MA_;
    
    %% Time Integration
    i = 1;
    r(:,:,1) = full(rnow);
    h = waitbar(0,'Running time integration');
    for t=0:dt:Run.time-dt
        rnow = sparse(r(:,:,i));
        
        ak = a(2)*rnow(:,1) + a(3)*rnow(:,2) + a(4)*rnow(:,3);
        bk = a(1)*rnow(:,1) + a(5)*rnow(:,2) + a(6)*rnow(:,3);
        
        %% Excitation Loads
        Fexc = ExcLoad(Run,data,t+dt);
        
        %% Saving Loads
        F(:,1,i) = full(-MA * rnow(:,3));
        F(:,2,i) = full(-B  * rnow(:,2));
        F(:,3,i) = full(-C  * rnow(:,1));
        F(:,4,i) = full(Fexc);
        
        %% Effective Exciting Loads
        F_ = Fexc + B*bk + MA*ak;
        
        rnew(:,1) = sparseinv(C_) *F_;
        rnew(:,2) = a(1)*rnew(:,1) - bk;
        rnew(:,3) = a(2)*rnew(:,1) - ak;
        
        r(:,:,i+1) = full(rnew);
        i = i+1;
        waitbar((t+dt)/Run.time);
    end
    
    %% Saving Loads
    F(:,1,i+1) = full(-MA*rnew(:,3));
    F(:,2,i+1) = full(-B *rnew(:,2));
    F(:,3,i+1) = full(-C *rnew(:,1));
    F(:,4,i+1) = full(ExcLoad(Run,data,t+dt));
    close(h);
          
    
    
else %%non-linear
    
    %% Integration constats
    dt        = Run.dt; %Length of each step
    gamma     = 0.5;    %No numerical damping
    beta      = 1/6;    %Linear acceleration
    
    a(1) = gamma/(beta*dt);
    a(2) = 1/(beta*dt^2);
    a(3) = 1/(beta*dt);
    a(4) = 1/(2*beta); %% From Langen & Sigbjrnsson (text before non-linear algoritm)
    a(5) = gamma/beta;
    a(6) = (gamma/(2*beta) -1)*dt;
    a(7) = a(5) - 1;
    a(8) = (1 - gamma)*dt;
    a(9) = gamma*dt;
    
    %% Mass matrix (linear)
    MA   = Inertia(data,zeros(6,3),1);
        
    %% Damping Matrix (linear)
    B    = Damping(data,zeros(6,3),Run,1);
    
    %% Contribution to Effectiv Stifness
    B_   = B  * a(1);
    MA_  = MA * a(2);
    
    %% Time Integration
    i = 1;
    r(:,:,1) = full(rnow);
    h = waitbar(0,'Running time integration');
    for t=0:dt:Run.time-dt
        rnow = sparse(r(:,:,i));
        %% Inertia Loads
        Fi = -MA*rnow(:,3);
        %% Damping Loads
        Fd = -B *rnow(:,2);
        % Restoring Loads and Stiffness Matrix
        [C Fr] = Restoring(data,rnow,3,Zeta(Run,rnow,t));
        %% Excitation Loads
        Fexc = ExcLoad(Run,data,t+dt);
        
        %% Saving Loads
        F(:,1,i) = full(Fi);
        F(:,2,i) = full(Fd);
        F(:,3,i) = full(Fr);
        F(:,4,i) = full(Fexc);
        
        %% Effective Stifness
        C_ = C + B_ + MA_;

        %% Effectiv Load Vector
        ak = a(3)*rnow(:,2) + a(4)*rnow(:,3);
        bk = a(5)*rnow(:,2) + a(6)*rnow(:,3);
        
        dF_ = Fexc + B*bk + MA*ak + Fi + Fd + Fr;
        
        %% Incremental Displacent, Speed and Acceleration
        dr   = sparseinv(C_)*dF_;
        drd  = a(1)*dr - bk;
        drdd = a(2)*dr - ak;
        
        %% Estimation of Displacent, Speed and Acceleration at i+1
        rnew = rnow + [dr drd drdd];

        % Residual Loads
        eF =  Fr - MA * rnew(:,3) ...
            - B * rnew(:,2) + Restoring(data,rnew,2,Zeta(Run,rnew,t+dt));    
        
        %% Displacement, Velocity and Acceleration Errors
        delta   = sparseinv(C_) * eF;
        deltad  = a(1)*delta;
        deltadd = a(2)*delta;
        
        error = tollim(rnew,delta);
        
        j = 1;
        %% Iteration
        while error > 0.005
            
            %% New Incrmental Displacement, Speed and Acceleration
            dr   = dr   + delta;
            drd  = drd  + deltad;
            drdd = drdd + deltadd;
            
            %% New Approximation of Displacement, Speed and Acceleration 
            rnew(:,1) = rnow(:,1) + dr;
            rnew(:,2) = rnow(:,2) + drd;
            rnew(:,3) = rnow(:,3) + drdd;
            
            %% Residual Loads
            eF =  ExcLoad(Run,data,t+dt) ...
                -MA * rnew(:,3) - B * rnew(:,2) + ...
                Restoring(data,rnew,2,Zeta(Run,rnew,t+dt));
            
            %% New Seffective Stiffness (Newton-Raphson)
            C = Restoring(data,rnew,1,Zeta(Run,rnew,t+dt));
            C_ = C + B_ + MA_;
            
            %% Displacement Error
            delta = sparseinv(C_) * eF;
            deltad  = a(1)*delta;
            deltadd = a(2)*delta;
            
            if j == 1000
                disp([' Warning: No Convergence at ' num2str(t) ' seconds'])
                dr   = sparseinv(C_)*dF_;
                drd  = a(1)*dr - bk;
                drdd = a(2)*dr - ak;
                break
            end
            error = tollim(rnew,delta);
            j=j+1;
        end
        r(:,:,i+1) = full(rnow + [dr drd drdd]);
        i = i+1;
        waitbar((t+dt)/Run.time);
    end
    
    %% Saving Loads
    F(:,1,i+1) = full(-MA*rnew(:,3));
    F(:,2,i+1) = full(-B *rnew(:,2));
    F(:,3,i+1) = full(Restoring(data,rnew,2,Zeta(Run,rnew,t+dt)));
    F(:,4,i+1) = full(ExcLoad(Run,data,t+dt));
    
    close(h);
end
end
