function Plotalot(t,r,F,RAO,Run)

if Run.output == 1 %% Response Amplitude Operator
    h = waitbar(0,'Preparing plots...');
    eta1 = zeros(1,length(RAO));
    eta3 = zeros(1,length(RAO));
    eta5 = zeros(1,length(RAO));
    for i=1:length(RAO)
        eta1(i) = RAO(1,i);
        eta3(i) = RAO(3,i);
        eta5(i) = RAO(5,i);
        waitbar(i/length(RAO))
    end
    close(h) 
    xax = Run.omega(1):(Run.omega(2)-Run.omega(1))/100:Run.omega(2);

    figure('position',[420 528 500 320])
    plot(xax,eta1);
    title('$$\mbox{Surge Response Amplitude Operator}$$','Interpreter','latex')
    ylabel('$$\frac{\eta_{1}}{\zeta_{A}} [-]$$','Interpreter','latex')
    xlabel('$$\omega [s^{-1}]$$','Interpreter','latex')
    box on
    
    figure('position',[420 528 500 320])
    plot(xax,eta3);
    title('$$\mbox{Heave Response Amplitude Operator}$$','Interpreter','latex')
    ylabel('$$\frac{\eta_{5}}{\zeta_{A}} [-]$$','Interpreter','latex')
    xlabel('$$\omega [s^{-1}]$$','Interpreter','latex')
    box on
    
    figure('position',[420 528 500 320])
    plot(xax,eta5*180/pi);
    title('$$\mbox{Surge Response Amplitude Operator}$$','Interpreter','latex')
    ylabel('$$\frac{\eta_{5}}{\zeta_{A}} \left[\frac{^{o}}{m}\right]$$','Interpreter','latex')
    xlabel('$$\omega [s^{-1}]$$','Interpreter','latex')
    box on



elseif Run.envload == 2 %% Ice
    h = waitbar(0,'Preparing plots...');
    eta1R = zeros(1,size(r,3));
    eta1C = zeros(1,size(r,3));
    eta5R = zeros(1,size(r,3));
    eta5C = zeros(1,size(r,3));
    F1R = zeros(1,size(r,3));
    F1C = zeros(1,size(r,3));
    F3R = zeros(1,size(r,3));
    F3C = zeros(1,size(r,3));
    F5R = zeros(1,size(r,3));
    F5C = zeros(1,size(r,3));
    for i = 1:size(r,3)
        eta1R(i) = r(1,1,i);
        eta1C(i) = r(1,2,i);
        eta5R(i) = r(5,1,i);
        eta5C(i) = r(5,2,i);
        F1R(i) = F(1,1,i);
        F1C(i) = F(1,2,i);
        F3R(i) = F(3,1,i);
        F3C(i) = F(3,2,i);
        F5R(i) = F(5,1,i);
        F5C(i) = F(5,2,i);
        waitbar(i/size(r,3))
    end
    close(h);
    xax = Run.Hice(1):(Run.Hice(2)-Run.Hice(1))/50:Run.Hice(2);
    
    figure('position',[420 528 500 320])
    hold on
    plot(xax,eta1R,'color',[0.3 0.3 1]);
    plot(xax,eta1C,'color',[0.7 0.7 0]);
    hold off
    title('$$\mbox{Static Drift-Off}$$','Interpreter','latex')
    ylabel('$$\eta_{1} [m]$$','Interpreter','latex')
    xlabel('$$\mbox{Ice thickness, H} [m]$$','Interpreter','latex')
    hleg = legend('$$\mbox{Ralston}$$',...  
       '$$\mbox{Croasdale}$$','location','southwest');
    set(hleg,'Interpreter','latex');
    box on
    
    figure('position',[420 528 500 320])
    hold on
    plot(xax,eta5R.*180./pi,'color',[0.3 0.3 1]);
    plot(xax,eta5C.*180./pi,'color',[0.7 0.7 0]);
    hold off
    title('$$\mbox{Static Heeling}$$','Interpreter','latex')
    ylabel('$$\eta_{5} [^{o}]$$','Interpreter','latex')
    xlabel('$$\mbox{Ice thickness, H} [m]$$','Interpreter','latex')
    hleg = legend('$$\mbox{Ralston}$$',...  
       '$$\mbox{Croasdale}$$','location','southwest');
    set(hleg,'Interpreter','latex');
    box on
    
    figure('position',[420 528 500 320])
    hold on
    plot(xax,F1R*10^-6,'color',[0.3 0.3 1]);
    plot(xax,F1C*10^-6,'color',[0.7 0.7 0]);
    hold off
    title('$$\mbox{Horizontal Force}$$','Interpreter','latex')
    ylabel('$$F_{1}^{E,Ice} [MN]$$','Interpreter','latex')
    xlabel('$$\mbox{Ice thickness, H} [m]$$','Interpreter','latex')
    hleg = legend('$$\mbox{Ralston}$$',...  
       '$$\mbox{Croasdale}$$','location','southwest');
    set(hleg,'Interpreter','latex');
    box on
    
    figure('position',[420 528 500 320])
    hold on
    plot(xax,F3R*10^-6,'color',[0.3 0.3 1]);
    plot(xax,F3C*10^-6,'color',[0.7 0.7 0]);
    hold off
    title('$$\mbox{Vertical Force}$$','Interpreter','latex')
    ylabel('$$F_{3}^{E,Ice} [MN]$$','Interpreter','latex')
    xlabel('$$\mbox{Ice thickness, H} [m]$$','Interpreter','latex')
    hleg = legend('$$\mbox{Ralston}$$',...  
       '$$\mbox{Croasdale}$$','location','northwest');
    set(hleg,'Interpreter','latex');
    box on
    
    figure('position',[420 528 500 320])
    hold on
    plot(xax,F5R*10^-6,'color',[0.3 0.3 1])
    plot(xax,F5C*10^-6,'color',[0.7 0.7 0])
    hold off
    title('$$\mbox{Pitching Moment}$$','Interpreter','latex')
    ylabel('$$F_{5}^{E,Ice} [MNm]$$','Interpreter','latex')
    xlabel('$$\mbox{Ice thickness, H} [m]$$','Interpreter','latex')
    hleg = legend('$$\mbox{Ralston}$$',...  
       '$$\mbox{Croasdale}$$','location','southwest');
    set(hleg,'Interpreter','latex');
    box on


else  %% Time Series
    h       = waitbar(0,'Preparing plots...');
    s       = zeros(6,length(t));
    V       = zeros(6,length(t));
    a       = zeros(6,length(t));
    Fi      = zeros(6,length(t));
    Fd      = zeros(6,length(t));
    Fr      = zeros(6,length(t));
    Fexc    = zeros(6,length(t));
    for i=1:length(t)
        s(:,i) = r(:,1,i);
        V(:,i) = r(:,2,i);
        a(:,i) = r(:,3,i);
        Fi(:,i) = F(:,1,i);
        Fd(:,i) = F(:,2,i);
        Fr(:,i) = F(:,3,i);
        Fexc(:,i) = F(:,4,i);
        waitbar(i/length(t))
    end
    close(h);
    xax = t;
    
    figure('position',[420 528 500 320])
    plot(xax,s(1,:));
    title('$$\mbox{Surge Motion}$$','Interpreter','latex')
    ylabel('$$\eta_{1}[m]$$','Interpreter','latex')
    xlabel('$$t [s]$$','Interpreter','latex')
    box on    
    
    figure('position',[420 528 500 320])
    plot(xax,s(3,:));
    title('$$\mbox{Heave Motion}$$','Interpreter','latex')
    ylabel('$$\eta_{3}[m]$$','Interpreter','latex')
    xlabel('$$t [s]$$','Interpreter','latex')
    box on 
    
    figure('position',[420 528 500 320])
    plot(xax,180/pi.*s(5,:));
    title('$$\mbox{Pitch Motion}$$','Interpreter','latex')
    ylabel('$$\eta_{5}[^{o}]$$','Interpreter','latex')
    xlabel('$$t [s]$$','Interpreter','latex')
    box on 
    
    figure('position',[420 528 500 320])
    plot(xax,V(1,:));
    title('$$\mbox{Surge Velocity}$$','Interpreter','latex')
    ylabel('$$\dot{\eta}_{1}\left[\frac{m}{s}\right]$$','Interpreter','latex')
    xlabel('$$t [s]$$','Interpreter','latex')
    box on 
    
    figure('position',[420 528 500 320])
    plot(xax,V(3,:));
    title('$$\mbox{Heave Velocity}$$','Interpreter','latex')
    ylabel('$$\dot{\eta}_{3}\left[\frac{m}{s}\right]$$','Interpreter','latex')
    xlabel('$$t [s]$$','Interpreter','latex')
    box on 
    
    figure('position',[420 528 500 320])
    plot(xax,V(5,:)*180/pi);
    title('$$\mbox{Pitch Velocity}$$','Interpreter','latex')
    ylabel('$$\dot{\eta}_{5}\left[^{o}s^{-1}\right]$$','Interpreter','latex')
    xlabel('$$t [s]$$','Interpreter','latex')
    box on 
    
    figure('position',[420 528 500 320])
    plot(xax,a(1,:));
    title('$$\mbox{Surge Acceleration}$$','Interpreter','latex')
    ylabel('$$\ddot{\eta}_{1}\left[\frac{m}{s^{2}}\right]$$','Interpreter','latex')
    xlabel('$$t [s]$$','Interpreter','latex')
    box on 
    
    figure('position',[420 528 500 320])
    plot(xax,a(3,:));
    title('$$\mbox{Heave Acceleration}$$','Interpreter','latex')
    ylabel('$$\ddot{\eta}_{3}\left[\frac{m}{s^{2}}\right]$$','Interpreter','latex')
    xlabel('$$t [s]$$','Interpreter','latex')
    box on 
    
    figure('position',[420 528 500 320])
    plot(xax,a(5,:)*180/pi);
    title('$$\mbox{Pitch Acceleration}$$','Interpreter','latex')
    ylabel('$$\ddot{\eta}_{5}\left[^{o}s^{-2}\right]$$','Interpreter','latex')
    xlabel('$$t [s]$$','Interpreter','latex')
    box on 
    
    figure('position',[420 528 500 320])
    plot(xax,10^-6*Fi(1,:),xax,10^-6*Fd(1,:),xax,10^-6*Fr(1,:),xax,10^-6*Fexc(1,:));
    title('$$\mbox{Surge Forces}$$','Interpreter','latex')
    ylabel('$$F_{1}[MN]$$','Interpreter','latex')
    xlabel('$$t [s]$$','Interpreter','latex')
    hleg = legend('$$\mbox{Inertia}$$',...  
       '$$\mbox{Damping}$$',...
       '$$\mbox{Restoring}$$',...
       '$$\mbox{Excitation}$$','location','BestOutside');
    set(hleg,'Interpreter','latex');
    box on  
    
    figure('position',[420 528 500 320])
    plot(xax,10^-6*Fi(3,:),xax,10^-6*Fd(3,:),xax,10^-6*Fr(3,:),xax,10^-6*Fexc(3,:));
    title('$$\mbox{Heave Forces}$$','Interpreter','latex')
    ylabel('$$F_{3}[MN]$$','Interpreter','latex')
    xlabel('$$t [s]$$','Interpreter','latex')
    hleg = legend('$$\mbox{Inertia}$$',...  
       '$$\mbox{Damping}$$',...
       '$$\mbox{Restoring}$$',...
       '$$\mbox{Excitation}$$','location','BestOutside');
    set(hleg,'Interpreter','latex');
    box on
    
    figure('position',[420 528 500 320])
    plot(xax,10^-6*Fi(5,:),xax,10^-6*Fd(5,:),xax,10^-6*Fr(5,:),xax,10^-6*Fexc(5,:));
    title('$$\mbox{Pitch Moments}$$','Interpreter','latex')
    ylabel('$$F_{5}[MN]$$','Interpreter','latex')
    xlabel('$$t [s]$$','Interpreter','latex')
    hleg = legend('$$\mbox{Inertia}$$',...  
       '$$\mbox{Damping}$$',...
       '$$\mbox{Restoring}$$',...
       '$$\mbox{Excitation}$$','location','BestOutside');
    set(hleg,'Interpreter','latex');
    box on
    
end
end