function [Fs Fc] = WaveLoads(Run,data)

g = data.env.g;
rho = data.env.rho;
d = data.body.d;
KG = data.body.KG;

COG = d-KG;

z = data.body.z;
x = data.body.x;

zetaA = Run.zetaA;
if Run.T == inf
    omega = 0.01;
    k = 0.01;
elseif Run.T ~= 0
    omega = 2*pi/Run.T;
    k = omega^2/g;
end

Fs = zeros(6,1);
Fc = zeros(6,1);

%% Froude-Krylov Forces
if z(1) == z(2)   %% If Flat Bottom
    %% proportional to sin(omega*t)
    Fs(3) = Fs(3) + 2/k*zetaA*rho*g*exp(-k*z(1))*pi*x(2)...
        *besselj(1, k*x(2)); %%From Maple
    %% proportional to cos(omega*t)
    Fc(5) = Fc(5) + 2/k^2*zetaA*rho*g*exp(-k*z(1))*pi*x(2)...
        *(k*besselj(0, k*x(2))*x(2)-2*besselj(1, k*x(2))); %%From Maple
    n=2;    
else
    n=1;
end
for i = n:find( z == 0)-1
    if z(i+1) == z(i)
        a=0;
    else
        a = ( x(i+1)-x(i) ) / ( z(i+1) - z(i) );
    end
    
    iiota1 = sin(atan(a));
    iota3 = cos(atan(a));
    
    %% proportional to sin(omega*t)
    Fs(3) = Fs(3) + ...
        2*rho*g*zetaA*iota3*pi/k^2*...
        (-exp(z(i)*k)*k*x(i)+exp(z(i)*k)*a-exp(z(i)*k)*k*a*z(i)+...
        exp(z(i+1)*k)*k*x(i)-exp(z(i+1)*k)*a+exp(z(i+1)*k)*k*a*z(i+1));
        %%From Maple
    %% proportional to cos(omega*t)
    Fc(1) = Fc(1) + ...
        pi*iiota1*zetaA*g*rho/k^2*...
        (-2*exp(z(i)*k)*a*k*x(i)+exp(z(i)*k)*k^2*x(i)^2+2*exp(z(i)*k)*...
        a^2+2*exp(z(i)*k)*a*k^2*x(i)*z(i)+exp(z(i)*k)*a^2*k^2*z(i)^2-2*...
        exp(z(i)*k)*a^2*k*z(i)+2*exp(z(i+1)*k)*a*k*x(i)-exp(z(i+1)*k)*...
        k^2*x(i)^2-2*exp(z(i+1)*k)*a^2-2*exp(z(i+1)*k)*a*k^2*x(i)*...
        z(i+1)-exp(z(i+1)*k)*a^2*k^2*z(i+1)^2+2*exp(z(i+1)*k)*...
        a^2*k*z(i+1)); %%From Maple
    
    Fc(5) = Fc(5) +...
        pi*zetaA*g*rho/k^3*...
        (-6*exp(z(i)*k)*a^3*iota3-6*exp(z(i)*k)*a^2*iiota1+6*...
        exp(z(i+1)*k)*a^3*iota3+6*exp(z(i+1)*k)*a^2*iiota1+exp(z(i)*k)*...
        k^3*iota3*x(i)^3-3*exp(z(i)*k)*iota3*a*x(i)^2*k^2+exp(z(i)*k)*...
        k^3*iiota1*x(i)^2*COG+exp(z(i)*k)*iiota1*a^2*k^3*z(i)^3+...
        exp(z(i)*k)*iiota1*k^3*x(i)^2*z(i)+exp(z(i)*k)*iota3*a^3*k^3*...
        z(i)^3+3*exp(z(i+1)*k)*a^3*k^2*iota3*z(i+1)^2+3*exp(z(i+1)*k)*...
        a^2*k^2*iiota1*z(i+1)^2-3*exp(z(i)*k)*iiota1*a^2*k^2*z(i)^2+6*...
        exp(z(i)*k)*iiota1*a^2*k*z(i)+2*exp(z(i)*k)*a^2*iiota1*COG*k+2*...
        exp(z(i)*k)*iiota1*k^3*a*x(i)*COG*z(i)+6*exp(z(i)*k)*a^2*x(i)*...
        iota3*k+6*exp(z(i)*k)*iota3*a^3*k*z(i)+3*exp(z(i+1)*k)*iota3*a*...
        x(i)^2*k^2-exp(z(i+1)*k)*k^3*iiota1*x(i)^2*COG-6*exp(z(i+1)*k)*...
        a^2*iiota1*k*z(i+1)-4*exp(z(i+1)*k)*x(i)*a*iiota1*k-3*...
        exp(z(i)*k)*iota3*a^3*k^2*z(i)^2+4*exp(z(i)*k)*x(i)*a*...
        iiota1*k-exp(z(i+1)*k)*a^2*k^3*iiota1*z(i+1)^3-6*...
        exp(z(i+1)*k)*k*a^3*iota3*z(i+1)-6*exp(z(i+1)*k)*a^2*...
        x(i)*iota3*k-exp(z(i+1)*k)*a^3*k^3*iota3*z(i+1)^3-2*...
        exp(z(i+1)*k)*a^2*iiota1*COG*k+exp(z(i+1)*k)*iiota1*x(i)^2*...
        k^2-2*exp(z(i+1)*k)*k^3*iiota1*x(i)*a*COG*z(i+1)-exp(z(i+1)*k)*...
        k^3*iiota1*x(i)^2*z(i+1)+exp(z(i)*k)*iiota1*a^2*k^3*COG*z(i)^2-...
        2*exp(z(i)*k)*iiota1*x(i)*a*COG*k^2-2*exp(z(i)*k)*iiota1*k^2*...
        COG*a^2*z(i)+3*exp(z(i)*k)*iota3*a*k^3*x(i)^2*z(i)-6*...
        exp(z(i)*k)*iota3*a^2*k^2*x(i)*z(i)-4*exp(z(i)*k)*iiota1*a*...
        x(i)*k^2*z(i)+3*exp(z(i)*k)*iota3*a^2*k^3*x(i)*z(i)^2+2*...
        exp(z(i)*k)*iiota1*a*k^3*x(i)*z(i)^2+2*exp(z(i+1)*k)*iiota1*...
        x(i)*a*COG*k^2-3*exp(z(i+1)*k)*k^3*iota3*a*x(i)^2*z(i+1)-...
        exp(z(i+1)*k)*a^2*k^3*iiota1*COG*z(i+1)^2+4*exp(z(i+1)*k)*...
        iiota1*x(i)*a*k^2*z(i+1)-2*exp(z(i+1)*k)*a*k^3*iiota1*x(i)*...
        z(i+1)^2+2*exp(z(i+1)*k)*k^2*a^2*iiota1*COG*z(i+1)-3*...
        exp(z(i+1)*k)*a^2*k^3*x(i)*iota3*z(i+1)^2+6*exp(z(i+1)*k)*...
        k^2*a^2*x(i)*iota3*z(i+1)-exp(z(i)*k)*iiota1*x(i)^2*...
        k^2-exp(z(i+1)*k)*k^3*iota3*x(i)^3);

end
%% Diffraction Loads
A = Inertia(data,zeros(6,3),4);

 %% Finding Volume Center
vol = zeros(1,find(z == 0) - 1);
zc = zeros(size(vol));
Vz = 0;

for i = 1:find( z == 0)-1
    vol(i) = pi/3 * (z(i+1) - z(i)) * ...
        (x(i)^2 + x(i)*x(i+1) + x(i+1)^2); 
    c = x(i)/x(i+1);
    zc(i)  = z(i) + (z(i+1) - ...
        z(i))/4 * (c^2 + 2*c +3)/(c^2 + 2*c +1);
end
for i = 1:length(vol);
    Vz = Vz + vol(i)*zc(i);
end
z_ = Vz/sum(vol);
 %% proportional to sin(omega*t)
Fs(3) = Fs(3) + ...
    A(3,3) * -omega^2*zetaA * exp(k*z_);

 %% proportional to cos(omega*t)
Fc(1) = Fc(1) + ...
    A(1,1) * omega^2*zetaA * exp(k*z_);
Fc(5) = Fc(5) + ...
    A(1,1) * omega^2*zetaA * exp(k*z_)*...
    (z_ - d + KG);

end