%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                              ConicalWedge.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Description: This function calculates the sizes of the conical wedges
%which needs to be found when the structure is pitching for the restoring
%forces
%
%Called by: Restoring
%
%Calls: Simpsons
%
%Outputs: C, Fr
%
%Version: 1.0
%Written by: Nils Gunnar Viko and Einar B. Glomnes
%
%Version: 1.0
%Written by: Jon Marius Aasheim, 2012
%Verifed, more comments and restructuring of the code.
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function [Vol xc zc] = ConicalWedge(r,a,m)

alpha       =       0;
beta        =       pi/2;

N = 8;

theta       =       zeros(1,N+1);

for i = 2:N
    
    %for use in the simpsons method
    theta(i)     =     (beta-alpha)/N * (i-1);
    
end

theta(N+1)  =       beta;
%% The formulas helps to find volume, and the volumetric center coordinates
f           =       1/3 .* r^3 .* m .* cos(theta).*(2-a.*m.*cos(theta))./...
                    (1-2.*a.*m.*cos(theta)+a^2*m^2.*cos(theta).^2);

g           =       -1/6 * m * r^4 * ((cos(theta)).^2 .*...
                    (a^2*m^2.*(cos(theta)).^2-3*a*m.*cos(theta)+3))./...
                    (-1+3*a*m.*cos(theta)-3*a^2*m^2.*(cos(theta)).^2+...
                    a^3*m^3.*(cos(theta)).^3);

h           =       1/12 .* r^4 .* m^2 .* ((cos(theta)).^2 .* ...
                    (a.*m.*cos(theta)-3))./(-1+3.*a.*m.*cos(theta)-3.*a^2. ...
                    *m^2.*(cos(theta)).^2+a^3*m^3.*(cos(theta)).^3);

%% Applies the simpsons method with the values above to find the total values                 
Vol         =       Simpsons(theta,f);
Vxc         =       Simpsons(theta,g);
Vzc         =       Simpsons(theta,h);
    
if m ~= 0
    
    xc      =       Vxc/Vol;
    
    zc      =       Vzc/Vol;
else
    
    xc      =       (3*pi/16*r);
    zc      =       0;
    
end
end