function data = DataInput

%% Environmental input (Ice further down)

data.env.h          = 320;      %% Waterdepth [m]
data.env.rho        = 1025;     %% Water density [kg/m^3]
data.env.g          = 9.81;     %% Acceleration of gravity [m/s^2]

%% Body Input

data.body.x         = [ 0  12   12 24 24 0 ];          %% x-coordinate of points defining buoy geometry [m]
data.body.z         = [-10.5 -10.5 -7  5  10 10];     %% z-coordinate of points defining buoy geometry [m]

data.body.xi        = [ 0  17.5 17.5  12   12  19 24 24  0];    %% x-coordinate of points defining buoy geometry used for inertia load calculations [m]
data.body.zi        = [-16 -16   -12 -8.5  -7   0 5  10  10];   %% z-coordinate of points defining buoy geometry used for inertia load calculations [m]

data.body.Nsec      = 90;                       %%Number of times the curves defined above is repeated in the revolved structure. 

data.body.r55       = 12.4;                     %% Radius of gyration in pitch [m]

data.body.KG        = 12.78;                    %% Distance between keel and CoG [m]
data.body.d         = abs(min(data.body.z));    %% Max draft [m] (found automatically)

data.body.rchr      = 19;                       %% Characteristic radius used for inertia calculations [m]
data.body.alpha     = 2.17;                     %% Added mass correction coefficient, heave [-]
data.body.beta(1)   = 1;                        %% Added mass correction coefficient, surge [-]
data.body.beta(2)   = 0.51;                     %% Added mass correction coefficient, surge-pitch coupling [-]
data.body.beta(3)   = 1.27;                     %% Added mass correction coefficient, pitch [-]

data.body.ksi1      = 0.043;                    %% Damping ratio, surge [-]
data.body.ksi3      = 0.068;                    %% Damping ratio, heave [-]
data.body.ksi5      = 0.036;                    %% Damping ratio, pitch [-]

%% Mooring input

data.mooring(1).TH0 = 2*cos(pi/4)*10^6;         %% Horizontal pretension [N]
data.mooring(1).w   = 4500;                     %% Submerged weight of line [kg/m]
data.mooring(1).l   = 1500;                     %% length of mooring line [m]
data.mooring(1).psi = 0;                        %% Angle between x-axis and mooring line [rad] (only works for 0 and pi)
data.mooring(1).zi  = -10.5;                    %% z-coordinate of connection point [m] 
data.mooring(1).xi  = 10;                       %% x-coordinate of connection point [m] 

data.mooring(2).TH0 = 2*cos(pi/4)*10^6;
data.mooring(2).w   = 4500;
data.mooring(2).l   = 1500;
data.mooring(2).psi = pi;
data.mooring(2).zi  = -10.5;
data.mooring(2).xi  = -15;

%% Ice

data.ice.rho        = 892;                      %% Density of ice [kg/m^3]
data.ice.sigmaf     = 500*10^3;                 %% Flexural strength of ice [Pa]
data.ice.E          = 5 * 10^9;                 %% Young's modulus of ice [Pa]
data.ice.nu         = 0.3;                      %% Poisson's ratio for ice [-]
data.ice.mu         = 0.20;                     %% Buoy-ice friction coefficient [-]

end