%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                              GZcalc.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Description: This function calculates the GZ arm for the structure, it is
%essential for the restoring force calculations.
%
%Called by: Restoring
%
%Calls: Vol, deltaVCalc, GZcalc
%
%Outputs: C, Fr
%
%Version: 1.0
%Written by: Nils Gunnar Viko and Einar B. Glomnes
%
%Version: 1.0
%Written by: Jon Marius Aasheim, 2012
%More comments and restructuring of the code.
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



function GZ = GZcalc(data,rnow)

x = data.body.x;
z = data.body.z;

radDwl  =       ( find( z == 0));

a       =       ( x(find(z == 0))-x(find(z == 0)-1) )...
                / ( z(find(z == 0)) - z(find(z == 0)-1) );

m       =       tan(rnow(5,1));

radWl   =       radDwl - a*rnow(3,1);

vol     =       zeros(1,find(z == 0) + 2);
xc      =       zeros(size(vol));
zc      =       zeros(size(vol));
Vx      =       0;
Vz      =       0;

for i = 1:find( z == 0)-1
    
    vol(i)      =       pi/3 * (z(i+1) - z(i)) * ...
                        (x(i)^2 + x(i)*x(i+1) + x(i+1)^2); 
    
    c           =       x(i)/x(i+1);
    
    xc(i)       =       0;
    
    zc(i)       =       z(i) + (z(i+1) - ...
                        z(i))/4 * (c^2 + 2*c +3)/(c^2 + c +1);
end

i=i+1; %% Volume Between DWL and WL
    
    vol(i)      =    pi/3 * (-rnow(3,1)-z(i)) * ...
                     (x(i)^2 + x(i)*radWl + radWl^2);
    
    c           =    x(i)/radWl;
    
    xc(i)       =    0;
    
    zc(i)       =    z(i) + (-rnow(3,1) - ...
                     z(i))/4 * (c^2 + 2*c +3)/(c^2 + c +1);
    
i=i+1; %% Conical Wedge in Positive x-direction

    [vol(i) x z] =      ConicalWedge(radWl,a,m);
    
    zc(i)        =      -rnow(3,1)+z;
    
    xc(i)        =      x;
    
i=i+1; %% Conical Wedge in Negative x-direction
    
    [vol(i) x z] =      ConicalWedge(radWl,a,-m);
    
    zc(i)        =      -rnow(3,1)+z;
    
    xc(i)        =      -x;
    
for i = 1:length(vol);
    
    Vx          =       Vx + vol(i)*xc(i);
    Vz          =       Vz + vol(i)*zc(i);
    
end

x_              =       Vx/sum(vol);
z_              =       Vz/sum(vol) + data.body.d - data.body.KG;

GZ              =       x_ * cos(rnow(5,1)) + z_ * sin(rnow(5,1));

end