%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                             HorPressure.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Description: This function calculates the horisontal pressure forces on
%the structure.
%
%Called by: Pressure.m
%
%Calls: none
%
%Outputs: Dynamic, Static
%
%Version: 1.0
%Written by: Jon Marius Aasheim, 2012
%
%Version:
%Written by: 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [Dynamic, Static]=HorPressure(data)

%Creates local variables for better readability
x       = data.body.xmid;
y       = data.body.ymid;
z       = data.body.zmid;
Area    = data.body.PanelArea;
t       = data.t;
rho     = data.env.rho;
g       = data.env.g;
ceta_a  = data.env.WaveHeight/2;
T       = data.env.WavePeriod;
depth   = data.env.h;
omega   = 2*pi/T;
k       = (omega^2)/g;

%calculates the normal vectors of the buoy
[Nx,~,~] = surfnorm(x,y,z);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Dynamic = 0;
Static=0;

for i=1:size(z,1)
    for j=1:size(z,2)
        if z(i,j)<=0
          
          ceta = ceta_a*sin(omega*t-k*x(i,j));
            
          zw = (z(i,j)-ceta)*(depth/(depth+ceta));
            
          Dynamic = Dynamic + Nx(i,j)*Area(i+1,1)*rho*g*ceta_a*...
              exp(k*zw)*sin(omega*t-k*x(i,j));

          Static = Static + Nx(i,j)*rho*g*zw*Area(i+1,1);

        else

          Dynamic = Dynamic + 0;
          
          Static = Static + 0;
          
        end
    end
end