%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                              Inertia.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Description: This is a Relay function for the pressure force/moment
%calculations. It coordinates the different calculations of the pressure
%forces on the structure.
%
%Called by: Precalc
%
%Calls: 
%
%Outputs: data
%
%Version: 1.0
%Written by: Glomnes and Viko
%
%Version: 1.0
%Verfied, added comments and restructured the code, small modifications
%Written by: Jon Marius Aasheim, 2012
%This simple function might need to be changed to include frequency
%dependence, Mass calculations are OK, but added mass should be rewritten
%in separate function.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function varargout = Inertia(data)

rho   = data.env.rho;
V     = Vol(data);
r55   = data.body.r55;
rchr  = data.body.rchr;
alpha = data.body.alpha;
beta  = data.body.beta;

x = data.body.xi;
z = data.body.zi;
d = data.body.d;
KG = data.body.KG;



    
    M = zeros(6);
    A = zeros(6);
    M(1,1) = rho*V;
    M(3,3) = rho*V; 
    M(5,5) = rho*V*r55^2;
    
    A(1,1) = beta(1)*rho*V;
    A(1,5) = 0;
    for i = 1:find( z == 0)-1
        if z(i+1) == z(i)
            a=0;
        else
            a = ( x(i+1)-x(i) ) / ( z(i+1) - z(i) );
        end
        %not used in the new program
        A(1,5) = A(1,5) + (1/4*a^2*(z(i+1)^4-z(i)^4)+(1/3)*(2*x(i)*a+...
            a^2*(d-KG))*(z(i+1)^3-z(i)^3)+(1/2)*(x(i)^2+2*x(i)*a*...
            (d-KG))*(z(i+1)^2-z(i)^2)+x(i)^2*(d-KG)*(z(i+1)-z(i)))*...
            pi*beta(2)*rho;
    end
    
    A(5,1) = A(1,5);

    A(3,3) = alpha*rho*rchr^3;

    A(5,5) = 0;
    for i = 1:find( z == 0)-1
        if z(i+1) == z(i)
            a=0;
        else
            a = ( x(i+1)-x(i) ) / ( z(i+1) - z(i) );
        end
        %Verifed formulae below, used matlab to generate interpolation
        %function
        A(5,5) = A(5,5) + (1/5*a^2*(z(i+1)^5-z(i)^5)+(1/4)*(2*x(i)*a+...
            a^2*(2*d-2*KG))*(z(i+1)^4-z(i)^4)+(1/3)*(x(i)^2+2*x(i)*a*...
            (2*d-2*KG)+a^2*(d-KG)^2)*(z(i+1)^3-z(i)^3)+(1/2)*(x(i)^2*...
            (2*d-2*KG)+2*x(i)*a*(d-KG)^2)*(z(i+1)^2-z(i)^2)+x(i)^2*...
            (d-KG)^2*(z(i+1)-z(i)))*pi*beta(3)*rho;
    end
    
    varargout{1} = sparse(M);
    varargout{2} = sparse(A);
