%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                 Menu.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Description: This is the Graphical User Interface function, it is supposed
%to make the program more user friendly and faster to use. It also makes it
%possible to make the program into a standalone windows application. 
%This function has been written to be expandable, but it is advised that
%the MATLAB tool GUIDE is used
%
%Called by: start.m
%
%Calls: gui_mainfcn             Controlls the GUI, created by GUIDE
%       Menu_OpeningFcn         Runs before the GUI is shown, takes inputs,
%                               and freezes the outputs until START is
%                               pushed.   
%       guidata                 Updates the handles structure.
%       Menu_OutputFcn          Handles all outputs back to start.m and
%                               closes GUI window.
%       start_button_Callback   Runs when Start button is pushed and
%                               unfreezes the GUI so outputs are returned
%                               to start.
%       ice_TB_Callback         Ice calculations toggle, makes Ice 
%                               calculations visible.
%       motion_TB_Callback      motion analysis toggle, makes motion 
%                               analysis visible. 
%       AT_edit_Callback        Copies text and checks validity when input 
%                               is made.
%       AT_edit_CreateFcn       Sets properties
%       Ts_edit_Callback        Copies text and checks validity when input 
%                               is made.
%       Ts_edit_CreateFcn       Sets properties
%       WH_edit_Callback        Copies text and checks validity when input 
%                               is made.
%       WH_edit_CreateFcn       Sets properties
%       WP_edit_Callback        Copies text and checks validity when input 
%                               is made.
%       WP_edit_CreateFcn       Sets properties
%       minIT_edit_Callback     Copies text and checks validity when input 
%                               is made.
%       minIT_edit_CreateFcn    Sets properties
%       maxIT_edit_Callback     Copies text and checks validity when input 
%                               is made.
%       maxIT_edit_CreateFcn    Sets properties
%       HM_CB_Callback          The toggle value is returned to start.m
%       HF_CB_Callback          The toggle value is returned to start.m
%       PM_CB_Callback          The toggle value is returned to start.m
%       PF_CB_Callback          The toggle value is returned to start.m
%       CloseRequestFcn         Cancels the analysis and ends GUI
%Inputs: none
%
%Outputs: data.WantMotion, data.WantIce, data.analysis_time, data.time_step
%,data.wave_height, data.wave_period, data.WantHeaveMotion,
%data.WantHeaveForce, data.WantPitchMotion, data.WantPitchForce,
%data.minIce, data.maxIce
%
%Version: 1.0
%Written by: Jon Marius Aasheim, 2012
%Some code has been automatically generated by GUIDE
%
%Version:
%Written by: 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



function varargout = Menu(varargin)

%This GUI has been created with the help of the built in MATLAB tool GUIDE






%%
% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @Menu_OpeningFcn, ...
                   'gui_OutputFcn',  @Menu_OutputFcn, ...
                   'gui_LayoutFcn',  [], ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
   gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT

%%
% --- Executes just before Menu is made visible.

function Menu_OpeningFcn(hObject, eventdata, handles, varargin)

% Choose default command line output for Menu
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes Menu wait for user response (see UIRESUME)
uiwait(handles.figure1);

%%
% --- Outputs from this function are returned to the command line.

function varargout = Menu_OutputFcn(hObject, eventdata, handles)
%ALL OUTPUT TO start.m MUST BE ASSIGNED HERE
%Assigns output from the entire gui.  
varargout{1} = get(handles.motion_TB,'value');
varargout{2} = get(handles.ice_TB,'value');

%Motion analysis values
varargout{3} = str2double(get(handles.AT_text,'string'));
varargout{4} = str2double(get(handles.Ts_text,'string'));
varargout{5} = str2double(get(handles.WH_text,'string'));
varargout{6} = str2double(get(handles.WP_text,'string'));
    
varargout{7} = get(handles.HM_CB,'value');
varargout{8} = get(handles.HT_CB,'value');
varargout{9} = get(handles.HV_CB,'value');
varargout{10} = get(handles.HA_CB,'value');
varargout{11} = get(handles.HF_CB,'value');

varargout{12} = get(handles.PM_CB,'value');
varargout{13} = get(handles.PT_CB,'value');
varargout{14} = get(handles.PV_CB,'value');
varargout{15} = get(handles.PA_CB,'value');
varargout{16} = get(handles.PF_CB,'value');

varargout{17} = get(handles.SM_CB,'value');
varargout{18} = get(handles.ST_CB,'value');
varargout{19} = get(handles.SV_CB,'value');
varargout{20} = get(handles.SA_CB,'value');
varargout{21} = get(handles.SF_CB,'value');

%Ice analysis values
varargout{22} = str2double(get(handles.minIT_text,'string'));
varargout{23} = str2double(get(handles.maxIT_text,'string'));

varargout{24} = get(handles.Ice_motion,'value');
varargout{25} = get(handles.ice_xforce,'value');
varargout{26} = get(handles.Ice_heel,'value');
varargout{27} = get(handles.ice_heel_force,'value');



%all outputs must be above here

delete(handles.figure1);
return;
%%
% --- Executes on button press in start_button.

function start_button_Callback(hObject, eventdata, handles)

if get(handles.motion_TB,'value')==0 && get(handles.ice_TB,'value')==0
    errordlg('You must choose analysis','Bad Input','modal')
    uicontrol(hObject)
    return
else
uiresume(handles.figure1);
end

%%
% Executes on button press of Ice Calculations button.

function ice_TB_Callback(hObject, eventdata, handles)
% get(hObject,'Value') returns toggle state of ice_TB

WantIce = get(hObject,'Value');

if WantIce
    set(handles.ice_BG,'visible','on')
else
    set(handles.ice_BG,'visible','off')
end
%%
% Executes on button press of Motion Analysis button.
%
function motion_TB_Callback(hObject, eventdata, handles)
% get(hObject,'Value') returns toggle state of motion_TB
WantMotion = get(hObject,'Value');

if WantMotion
    set(handles.motion_BG,'visible','on')
else
    set(handles.motion_BG,'visible','off')
end

%% 
% Executes on finished entry in Analysis Time edit box

function AT_edit_Callback(hObject, eventdata, handles)

%str2double(get(hObject,'String')) returns contents of AT_edit as a double

user_entry = str2double(get(hObject,'String'));

% Ensures that input from user can only be a numerical value
if isnan(user_entry)
    %gives error message if illegal value is used and returns to main GUI
    %function
    errordlg('You must enter a numeric value','Bad Input','modal')
    uicontrol(hObject)
	return
else
    %Changes the textbox containing default value
    str = sprintf('%g',user_entry);
    set(handles.AT_text,'String',str);
end


% --- Executes during object creation, after setting all properties.
function AT_edit_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

%% 
%Executes on finished entry in Time Step edit box

function Ts_edit_Callback(hObject, eventdata, handles)

%str2double(get(hObject,'String')) returns contents of Ts_edit as a double
user_entry = str2double(get(hObject,'String'));

% Ensures that input from user can only be a numerical value
if isnan(user_entry)
    %gives error message if illegal value is used and returns to main GUI
    %function
    errordlg('You must enter a numeric value','Bad Input','modal')
    uicontrol(hObject)
	return
else
    %Changes the textbox containing default value
    str = sprintf('%g',user_entry);
    set(handles.Ts_text,'String',str);
end


% --- Executes during object creation, after setting all properties.
function Ts_edit_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


%% 
%Executes on finished entry in Wave Height edit box

function WH_edit_Callback(hObject, eventdata, handles)

%str2double(get(hObject,'String')) returns contents of WH_edit as a double
user_entry = str2double(get(hObject,'String'));

% Ensures that input from user can only be a numerical value
if isnan(user_entry)
    %gives error message if illegal value is used and returns to main GUI
    %function
    errordlg('You must enter a numeric value','Bad Input','modal')
    uicontrol(hObject)
	return
else
    %Changes the textbox containing default value
    str = sprintf('%g',user_entry);
    set(handles.WH_text,'String',str);
end



% --- Executes during object creation, after setting all properties.
function WH_edit_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

%% 
%Executes on finished entry in Wave Period edit box

function WP_edit_Callback(hObject, eventdata, handles)

%str2double(get(hObject,'String')) returns contents of WP_edit as a double
user_entry = str2double(get(hObject,'String'));

% Ensures that input from user can only be a numerical value
if isnan(user_entry)
    %gives error message if illegal value is used and returns to main GUI
    %function
    errordlg('You must enter a numeric value','Bad Input','modal')
    uicontrol(hObject)
	return
else
    %Changes the textbox containing default value
    str = sprintf('%g',user_entry);
    set(handles.WP_text,'String',str);
end

% --- Executes during object creation, after setting all properties.
function WP_edit_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

%% 
%Executes on finished entry in Min Ice Thickness edit box

function minIT_edit_Callback(hObject, eventdata, handles)

% str2double(get(hObject,'String')) returns contents of minIT_edit as a double
user_entry = str2double(get(hObject,'String'));

% Ensures that input from user can only be a numerical value
if isnan(user_entry)
    %gives error message if illegal value is used and returns to main GUI
    %function
    errordlg('You must enter a numeric value','Bad Input','modal')
    uicontrol(hObject)
	return
else
    %Changes the textbox containing default value
    str = sprintf('%g',user_entry);
    set(handles.minIT_text,'String',str);
end

% --- Executes during object creation, after setting all properties.
function minIT_edit_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


%% 
%Executes on finished entry in Max Ice Thickness edit box

function maxIT_edit_Callback(hObject, eventdata, handles)

% str2double(get(hObject,'String')) returns contents of maxIT_edit as a double
user_entry = str2double(get(hObject,'String'));

% Ensures that input from user can only be a numerical value
if isnan(user_entry)
    %gives error message if illegal value is used and returns to main GUI
    %function
    errordlg('You must enter a numeric value','Bad Input','modal')
    uicontrol(hObject)
	return
else
    %Changes the textbox containing default value
    str = sprintf('%g',user_entry);
    set(handles.maxIT_text,'String',str);
end

% --- Executes during object creation, after setting all properties.
function maxIT_edit_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

%%
% --- Executes on button press of Heave Motion check box.
function HM_CB_Callback(hObject, eventdata, handles)
% get(hObject,'Value') returns toggle state of HM_CB

% --- Executes on button press in Heave Force check box
function HF_CB_Callback(hObject, eventdata, handles)
% get(hObject,'Value') returns toggle state of HF_CB

% --- Executes on button press in Pitch motion check box.
function PM_CB_Callback(hObject, eventdata, handles)
% get(hObject,'Value') returns toggle state of PM_CB

% --- Executes on button press in Pitch force check box.
function PF_CB_Callback(hObject, eventdata, handles)
% get(hObject,'Value') returns toggle state of PF_CB


% --- Executes when user attempts to close GUI.
function figure1_CloseRequestFcn(hObject, eventdata, handles)

disp('Analysis cancelled')
set(handles.ice_TB,'value',0);
set(handles.motion_TB,'value',0);

uiresume(handles.figure1);


% --- Executes on button press in Ice_motion.
function Ice_motion_Callback(hObject, eventdata, handles)
% hObject    handle to Ice_motion (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of Ice_motion


% --- Executes on button press in ice_xforce.
function ice_xforce_Callback(hObject, eventdata, handles)
% hObject    handle to ice_xforce (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of ice_xforce


% --- Executes on button press in Ice_heel.
function Ice_heel_Callback(hObject, eventdata, handles)
% hObject    handle to Ice_heel (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of Ice_heel


% --- Executes on button press in ice_heel_force.
function ice_heel_force_Callback(hObject, eventdata, handles)
% hObject    handle to ice_heel_force (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of ice_heel_force


% --- Executes on button press in SM_CB.
function SM_CB_Callback(hObject, eventdata, handles)
% hObject    handle to SM_CB (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of SM_CB


% --- Executes on button press in SF_CB.
function SF_CB_Callback(hObject, eventdata, handles)
% hObject    handle to SF_CB (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of SF_CB


% --- Executes on button press in HA_CB.
function HA_CB_Callback(hObject, eventdata, handles)
% hObject    handle to HA_CB (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of HA_CB


% --- Executes on button press in PA_CB.
function PA_CB_Callback(hObject, eventdata, handles)
% hObject    handle to PA_CB (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of PA_CB


% --- Executes on button press in SA_CB.
function SA_CB_Callback(hObject, eventdata, handles)
% hObject    handle to SA_CB (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of SA_CB


% --- Executes on button press in HV_CB.
function HV_CB_Callback(hObject, eventdata, handles)
% hObject    handle to HV_CB (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of HV_CB


% --- Executes on button press in PV_CB.
function PV_CB_Callback(hObject, eventdata, handles)
% hObject    handle to PV_CB (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of PV_CB


% --- Executes on button press in SV_CB.
function SV_CB_Callback(hObject, eventdata, handles)
% hObject    handle to SV_CB (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of SV_CB


% --- Executes on button press in HT_CB.
function HT_CB_Callback(hObject, eventdata, handles)
% hObject    handle to HT_CB (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of HT_CB


% --- Executes on button press in PT_CB.
function PT_CB_Callback(hObject, eventdata, handles)
% hObject    handle to PT_CB (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of PT_CB


% --- Executes on button press in ST_CB.
function ST_CB_Callback(hObject, eventdata, handles)
% hObject    handle to ST_CB (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of ST_CB
