%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                              MomPressure.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Description: This function calculates the dynamic pressure moments on the
%structure as it moves. The statics are handled by the restoring
%coefficients
%
%Called by: Pressure
%
%Calls: Nothing
%
%Outputs: Dynamic, Static
%
%Version: 1.0
%Written by: Jon Marius Aasheim, 2012
%
%Version:
%Written by: 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [Dynamic, Static]=MomPressure(data, analysis)

%Creates local variables for better readability
x       = analysis.x1;
y       = data.body.ymid;
z       = analysis.z1;
Area    = data.body.PanelArea;
t       = data.t;
rho     = data.env.rho;
g       = data.env.g;
ceta_a  = data.env.WaveHeight/2;
T       = data.env.WavePeriod;
depth   = data.env.h;
omega   = 2*pi/T;
k       = (omega^2)/g;
KG      = data.body.KG;
d       = data.body.d;
depth   = data.env.h;

%Finds the normal vectors of the buoy
[Nx,~,Nz] = surfnorm(x,y,z);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Dynamic = 0;
Static=0;

for i=1:size(z,1)
    for j=1:size(z,2)
        if z(i,j)<=0
          
          ceta = ceta_a*sin(omega*t-k*x(i,j));
            
          zw = (z(i,j)-ceta)*(depth/(depth+ceta)); 
            
            
            
           Dynamic = Dynamic - Nx(i,j)*abs((z(i,j)-d+KG))*Area(i+1,1)*rho*g* ...
               ceta_a*exp(k*zw)*sin(omega*t-k*x(i,j));

          
          Dynamic = Dynamic + Nz(i,j)*x(i,j)*Area(i+1,1)*rho*g*ceta_a* ...
              exp(k*zw)*sin(omega*t-k*x(i,j));

         

        else

          Dynamic = Dynamic + 0;
          
          Static = Static + 0;
          
        end
    end
end