%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                              Plotter.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Description: This is the plotting function. It has the information and
%calculates that which is needed to generate the individual plots. Also
%contains a code to modify the appearance of the figures. The figures are
%plotted depending on the choices made in the GUI
%
%Called by: main
%
%Calls: 
%
%Outputs: figures
%
%Version: 1.0
%Written by: Jon Marius Aasheim, 2012
%
%Version:
%Written by: 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function Plotter(data, Results, Run)

if Run.WantMotion==1
    time = Run.AnalysisTime;
    dt   = Run.TimeStep;
    
    if Run.WantSurgeMotion==1
        
        figure(2)
        
        plot(dt:dt:time, Results.s1 )
        
        grid on
        title('Surge Motion')
        xlabel('Time [s]')
        ylabel('Surge Motion [m]')
        
        %Changes the figures so the axis will completely fill the figure
        fig = gcf;
        style = hgexport('factorystyle');
        style.Bounds = 'tight';
        hgexport(fig,'-clipboard',style,'applystyle', true);
        drawnow;
    else
        
    end
    
    if Run.WantHeaveMotion==1      
        
        figure(3)
        
        plot(dt:dt:time,Results.s3)
        
        grid on
        title('Heave Motion')
        xlabel('Time [s]')
        ylabel('Heave Motion [m]')
        
        %Changes the figures so the axis will completely fill the figure
        fig = gcf;
        style = hgexport('factorystyle');
        style.Bounds = 'tight';
        hgexport(fig,'-clipboard',style,'applystyle', true);
        drawnow;      
    else
        
    end
   
    if Run.WantPitchMotion==1
       
        figure(4)
        
        plot(dt:dt:time, Results.s5)
        
        grid on
        title('Pitch Motion')
        xlabel('Time [s]')
        ylabel('Pitch Motion [Degrees]')
        
        %Changes the figures so the axis will completely fill the figure
        fig = gcf;
        style = hgexport('factorystyle');
        style.Bounds = 'tight';
        hgexport(fig,'-clipboard',style,'applystyle', true);
        drawnow; 
    else
        
    end
    
        if Run.WantSurgeTransfer==1
        
        figure(5)
        a = Results.s1/(data.env.WaveHeight/2);
        
        plot(dt:dt:time, a )
        
        title('Surge Transfer')
        xlabel('Time [s]')
        ylabel('Amplitude [m/m]')
        
        %Changes the figures so the axis will completely fill the figure
        fig = gcf;
        style = hgexport('factorystyle');
        style.Bounds = 'tight';
        hgexport(fig,'-clipboard',style,'applystyle', true);
        drawnow; 
    else
        
    end
    
    if Run.WantHeaveTransfer==1      
        
        figure(6)
        a = Results.s3/(data.env.WaveHeight/2);
        plot(dt:dt:time, a)
        
        title('Heave Transfer')
        xlabel('Time [s]')
        ylabel('Amplitude [m/m]')
        
        %Changes the figures so the axis will completely fill the figure
        fig = gcf;
        style = hgexport('factorystyle');
        style.Bounds = 'tight';
        hgexport(fig,'-clipboard',style,'applystyle', true);
        drawnow;       
    else
        
    end
   
    if Run.WantPitchTransfer==1
       
        figure(7)
        
        a= Results.s5/(data.env.WaveHeight/2);
        
        plot(dt:dt:time, a )
        
        grid on
        title('Pitch Transfer')
        xlabel('Time [s]')
        ylabel('Amplitude [Deg/m]')
        
        %Changes the figures so the axis will completely fill the figure
        fig = gcf;
        style = hgexport('factorystyle');
        style.Bounds = 'tight';
        hgexport(fig,'-clipboard',style,'applystyle', true);
        drawnow; 
    else
        
    end
    
    if Run.WantSurgeVelocity==1
        
        figure(8)
        
        plot(dt:dt:time, Results.v1)
        
        grid on
        title('Surge Velocity')
        xlabel('Time [s]')
        ylabel('Surge Velocity [m/s]')
        
        %Changes the figures so the axis will completely fill the figure
        fig = gcf;
        style = hgexport('factorystyle');
        style.Bounds = 'tight';
        hgexport(fig,'-clipboard',style,'applystyle', true);
        drawnow; 
    else
        
    end
    
    if Run.WantHeaveVelocity==1      
        
        figure(9)
        
        grid on
        plot(dt:dt:time, Results.v3)
        
        title('Heave Velocity')
        xlabel('Time [s]')
        ylabel('Heave Velocity [m/s]')
        
        %Changes the figures so the axis will completely fill the figure
        fig = gcf;
        style = hgexport('factorystyle');
        style.Bounds = 'tight';
        hgexport(fig,'-clipboard',style,'applystyle', true);
        drawnow; 
    else
        
    end
   
    if Run.WantPitchVelocity==1
         
        figure(10)
        
        plot(dt:dt:time, Results.v5)
        
        grid on
        title('Pitch Velocity')
        xlabel('Time [s]')
        ylabel('Pitch Velocity [m/s]')
        
        %Changes the figures so the axis will completely fill the figure
        fig = gcf;
        style = hgexport('factorystyle');
        style.Bounds = 'tight';
        hgexport(fig,'-clipboard',style,'applystyle', true);
        drawnow; 
    else
        
    end
    
    if Run.WantSurgeAccel==1
        
        figure(11)
        
        plot(dt:dt:time, Results.a1)
        
        grid on
        title('Surge Acceleration')
        xlabel('Time [s]')
        ylabel('Surge Acceleration [m/s^2]')         
        
        %Changes the figures so the axis will completely fill the figure
        fig = gcf;
        style = hgexport('factorystyle');
        style.Bounds = 'tight';
        hgexport(fig,'-clipboard',style,'applystyle', true);
        drawnow; 
    else
        
    end
    
    if Run.WantHeaveAccel==1      
     
        figure(12)
        
        plot(dt:dt:time, Results.a3)
        
        grid on
        title('Heave Acceleration')
        xlabel('Time [s]')
        ylabel('Heave Acceleration [m/s^2]')       
        
        %Changes the figures so the axis will completely fill the figure
        fig = gcf;
        style = hgexport('factorystyle');
        style.Bounds = 'tight';
        hgexport(fig,'-clipboard',style,'applystyle', true);
        drawnow;  
    else
        
    end
    
    if Run.WantPitchAccel==1
         
        figure(13)
        
        plot(dt:dt:time, Results.a5)
        
        grid on
        title('Pitch Acceleration')
        xlabel('Time [s]')
        ylabel('Pitch Acceleration [m/s^2]')  
        
        %Changes the figures so the axis will completely fill the figure
        fig = gcf;
        style = hgexport('factorystyle');
        style.Bounds = 'tight';
        hgexport(fig,'-clipboard',style,'applystyle', true);
        drawnow; 
    else
        
    end
    
    if Run.WantSurgeForce==1
         
        figure(14)
        
        plot(dt:dt:time, Results.HorTotal)
        
        grid on
        title('Surge Force')
        xlabel('Time [s]')
        ylabel('Surge Force [N]')
        
        %Changes the figures so the axis will completely fill the figure
        fig = gcf;
        style = hgexport('factorystyle');
        style.Bounds = 'tight';
        hgexport(fig,'-clipboard',style,'applystyle', true);
        drawnow; 
    else
        
    end
    
    if Run.WantHeaveForce==1
         
        figure(15)
        
        plot(dt:dt:time,Results.VertTotal)
        
        grid on
        title('Heave Force')
        xlabel('Time [s]')
        ylabel('Heave Force [N]')  
        
        %Changes the figures so the axis will completely fill the figure
        fig = gcf;
        style = hgexport('factorystyle');
        style.Bounds = 'tight';
        hgexport(fig,'-clipboard',style,'applystyle', true);
        drawnow; 
    else
        
    end
    
    
    if Run.WantPitchMoment==1
        
        figure(16)
        
        plot(dt:dt:time,Results.MomTotal)
        
        grid on
        title('Pitch Moment')
        xlabel('Time [s]')
        ylabel('Pitch Moment [Nm]')
        
        %Changes the figures so the axis will completely fill the figure
        fig = gcf;
        style = hgexport('factorystyle');
        style.Bounds = 'tight';
        hgexport(fig,'-clipboard',style,'applystyle', true);
        drawnow; 
    else
        
    end
    
    
else
    
end


if Run.WantIce==1
    
    MaxIce = data.ice.MaxIce;
    
    MinIce = data.ice.MinIce;
    
    dstep =  (MaxIce - MinIce)/50;
    
    for i=1:size(Results.ice.r,3)
        
        
        
        xmotion(i) = Results.ice.r(1,1,i);
        
        heeling(i) = Results.ice.r(5,1,i);
        
        xforce(i) = Results.ice.F(1,1,i);
        
        heelmoment(i) = Results.ice.F(5,1,i);
        
        
        
    end
    
    if Run.WantIceMotion==1
        
        figure(17)
        
        plot(MinIce:dstep:MaxIce, xmotion)
        
        grid on
        title('X Motion')
        xlabel('Ice Thickness')
        ylabel('X Motion [m]')
        
        %Changes the figures so the axis will completely fill the figure
        fig = gcf;
        style = hgexport('factorystyle');
        style.Bounds = 'tight';
        hgexport(fig,'-clipboard',style,'applystyle', true);
        drawnow; 
    else
        
    end
    
    if Run.WantIceHeel==1
        
        figure(18)

        
        plot(MinIce:dstep:MaxIce, heeling)
        
        grid on
        title('Heeling')
        xlabel('Ice Thickness')
        ylabel('Heeling []')
        
        %Changes the figures so the axis will completely fill the figure
        fig = gcf;
        style = hgexport('factorystyle');
        style.Bounds = 'tight';
        hgexport(fig,'-clipboard',style,'applystyle', true);
        drawnow; 
    else
        
    end
    
    
    if Run.WantIceForce==1
        
        figure(19)
        
        plot(MinIce:dstep:MaxIce, xforce)
        
        grid on
        title('Horisontal Force')
        xlabel('Ice Thickness')
        ylabel('Horisontal Force [N]')
        
        %Changes the figures so the axis will completely fill the figure
        fig = gcf;
        style = hgexport('factorystyle');
        style.Bounds = 'tight';
        hgexport(fig,'-clipboard',style,'applystyle', true);
        drawnow; 
    else
        
    end
    
    
    if Run.WantIceHeelMoment==1
        
        figure(20)
        
        plot(MinIce:dstep:MaxIce, heelmoment)
        
        grid on
        title('Heeling Moment')
        xlabel('Ice Thickness')
        ylabel('Heeling Moment [Nm]')
        
        %Changes the figures so the axis will completely fill the figure
        fig = gcf;
        style = hgexport('factorystyle');
        style.Bounds = 'tight';
        hgexport(fig,'-clipboard',style,'applystyle', true);
        drawnow; 
    else
        
    end

    
else
    
end