%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                              Restoring.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Description: Calculates the initial volume of the structure.
%
%Called by: MotionAnalysis, IceCalc
%
%Calls: RestHydStat, RestMooring
%
%Outputs: C, Fr
%
%Version: 1.0
%Written by: Nils Gunnar Viko and Einar B. Glomnes
%
%Version: 1.0
%Written by: Jon Marius Aasheim, 2012
%Only comments have been added.
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function varargout = Restoring(data,rnow,call,zeta)

if ~ischar(zeta)
    rnow(3,1) = rnow(3,1) - zeta;
end    

%% This function is designed to be used multiple places in the original 
%program, and it is also used in both IceCalc and MotionAnalysis in the
%new program. There is much room for improvement
%It could be a good idea to break this into smaller pieces
%and use a simpler version in the motion calc.
%reduce if-sentences to increase speed.
if call == 1
    
    C = sparse(zeros(6));
    
    C = C + RestHydStat(data,rnow,1);
    C = C + RestMooring(data,rnow,1);
    
    varargout{1} = C;

elseif call == 2
    
    Fr = sparse(zeros(6,1));
    
    Fr = Fr + RestHydStat(data,rnow,2);
    Fr = Fr + RestMooring(data,rnow,2);
    
    varargout{1} = Fr;

elseif call == 3
    
    C  = sparse(zeros(6));
    Fr = sparse(zeros(6,1));
    
    C = C + RestHydStat(data,rnow,1);
    C = C + RestMooring(data,rnow,1);
    
    Fr = Fr + RestHydStat(data,rnow,2);
    Fr = Fr + RestMooring(data,rnow,2);
    
    varargout{1} = C;
    varargout{2} = Fr;
    
end
end