%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                              simpsons.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Description: Simpsons method is an numerical integration method
%
%Called by: Restoring
%
%Calls: 
%
%Outputs: Ainv
%
%Version: 1.0
%Written by: Nils Gunnar Viko and Einar B. Glomnes
%
%Version: 1.0
%Written by: Jon Marius Aasheim, 2012
%Verified, more comments and restructuring of the code.
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



function S = Simpsons(x,y)

%% Checking input
if min(size(x)) ~= 1
    S = 0;
    disp('Input Invalid')
    return
end
if min(size(y)) ~= 1
    S = 0;
    disp('Input Invalid')
    return
end
if sum(size(y) ~= size(x))
    S = 0;
    disp('Input Invalid')
    return
end

if mod(length(x),2) ~= 1
    S = 0;
    disp('Number of intervals must be even')
    return
end

%% Actual Calculation
%The method follows the theory closely, should
h = (x(length(x)) - x(1)) / (length(x)-1);
for i = 1:length(x)-1
    if abs( x(i+1) - (x(1) + i*h) ) > 0.001
        S = 0;
        disp('Uneven intervals')
        return
    end
end  

s0 = y(1) + y(length(y));

s1 = 0;
for i = 2:2:length(y)-1
    s1 = s1 + y(i);
end

s2 = 0;
for i = 3:2:length(y)-2
    s2 = s2 + y(i);
end

S = h/3*(s0+4*s1+2*s2);
end
%%