%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                              deltaVCalc.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Description: This function calculates the change in underwater volume when
%the structure moves in waves. The functions applied have been found with
%conic sections.
%
%Called by: RestHydStat
%
%Calls: Nothing
%
%Outputs: deltaV
%
%Version: 1.0
%Written by: Nils Gunnar Viko and Einar B. Glomnes
%
%Version: 1.0
%Written by: Jon Marius Aasheim, 2012
%Verified, more comments and restructuring of the code.
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function deltaV = deltaVCalc(data,rnow)

x      =  data.body.x;
z      =  data.body.z;

% Radius in the waterline
radDwl =  x(find(z == 0));

% Finds the angle in the waterline area
a      =  (   x(find(z == 0))  -  x(find(z == 0)-1) )...
          / ( z(find(z == 0))  -  z(find(z == 0)-1) );

      
%% If the buoy is straight in the waterline i.e a = 0
%deltaV will be the heave motion times the area in the waterline.
if a == 0
    
    deltaV = -pi*rnow(3,1) * radDwl^2;  

else
%% If the buoy is slanted in the waterline i.e a =/= 0
%deltaV must be calculated with conics (kjeglesnitt) 
    
    deltaV = -pi*rnow(3,1)/3 * (3*radDwl^2 - 3*radDwl*a*rnow(3,1) ...
             + a^2*rnow(3,1)^2) + pi/3 * (radDwl - a*rnow(3,1)^2)^3/a * ...
             ( 1/ (1-a^2*tan(rnow(5,1))^2)^(3/2) -1);
   
end

end